@@ -135,12 +135,17 @@ class DataCollection:
 
         if first_data_el is not None:
             yield (
-                ",".join(first_data_el.get(column) or "" for column in columns_to_store)
+                ",".join(
+                    f'"{first_data_el.get(column)}"' or ""
+                    for column in columns_to_store
+                )
                 + "\n"
             ).encode()
         for data_el in self:
             yield (
-                ",".join(data_el.get(column) or "" for column in columns_to_store)
+                ",".join(
+                    f'"{data_el.get(column)}"' or "" for column in columns_to_store
+                )
                 + "\n"
             ).encode()
 
@@ -213,21 +218,28 @@ class DataCollection:
         else:
             f = BytesIO()
             self.export_to_csv(f)
-            f.seek(0)
-            columns = BytesIO(f.getvalue()).readlines(1)[0].decode().strip().split(",")
-            datetime_cols = [c for c in columns if c.endswith("_time") or c == "time"]
-            df = pd.read_csv(
-                f,
-                parse_dates=datetime_cols,
-                dtype=dtype_mapper,
-                date_parser=isoparse,
-            )
-            if dtype_mapper is None:
-                df = df.convert_dtypes()
-            if header is not None:
-                assert len(df.columns) == len(
-                    header
-                ), "header length does not match output values"
-                df.columns = header
-
-            return df
+            if f.getbuffer().nbytes == 0:
+                logger.warning("Response is empty.")
+                return pd.DataFrame()
+            else:
+                f.seek(0)
+                columns = (
+                    BytesIO(f.getvalue()).readlines(1)[0].decode().strip().split(",")
+                )
+                datetime_cols = [
+                    c for c in columns if c.endswith("_time") or c == "time"
+                ]
+                df = pd.read_csv(
+                    f,
+                    parse_dates=datetime_cols,
+                    dtype=dtype_mapper,
+                    date_parser=isoparse,
+                )
+                if dtype_mapper is None:
+                    df = df.convert_dtypes()
+                if header is not None:
+                    assert len(df.columns) == len(
+                        header
+                    ), "header length does not match output values"
+                    df.columns = header
+                return df
